<?php

namespace Modules\Pp\Http\Controllers;

use Illuminate\Contracts\Support\Renderable;
use Illuminate\Http\Request;
use Illuminate\Routing\Controller;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Modules\Hr\Entities\EmployeeDesignation;
use Modules\Pp\Entities\ProductionTeam;

class ProductionTeamController extends Controller
{

    public function saveProductionTeam(Request $request)
    {
        try {
            $designation_id = $request->get('designation_id');
            $team = new ProductionTeam();
            $team->designation_id = $designation_id;
            $team->status = 1;
            $team->user_id = Auth::user()->id;
            $status = $team->save();
            $responseBody = $this->responseBody(true, "ProductionTeamController", "saveProductionTeam", $status);
        } catch (\Exception $ex) {
            $responseBody = $this->responseBody(false, "ProductionTeamController", "saveProductionTeam", $ex);
        }
        return response()->json(["data" => $responseBody]);
    }


    public function allDesignation()
    {
        try {
            $designation = EmployeeDesignation::where('status', '=', '1')->get();
            $responseBody = $this->responseBody(true, "ProductionTeamController", "allDesignation", $designation);
        } catch (\Exception $ex) {
            $responseBody = $this->responseBody(false, "ProductionTeamController", "allDesignation", $ex);
        }
        return response()->json(["data" => $responseBody]);
    }



    public function productionTeamList()
    {
        try {
            $designations = DB::select("SELECT pp_production_teams.*,hr_employee_designations.designation FROM pp_production_teams INNER JOIN hr_employee_designations ON pp_production_teams.designation_id = hr_employee_designations.designation_id");
            $responseBody = $this->responseBody(true, "ProductionTeamController", "productionTeamList", $designations);
        } catch (\Exception $ex) {
            $responseBody = $this->responseBody(false, "ProductionTeamController", "productionTeamList", $ex);
        }
        return response()->json(["data" => $responseBody]);
    }



    public function productionTeamDelete($id,$designation_id)
    {
        try {
            $assigned = $this->isAssigned($designation_id);
            if ($assigned) {
                $responseBody = $this->responseBody(false, "disable", "assigned", $assigned);
                return response()->json(["data" => $responseBody]); //if allready assigned settings, terminate this function
            }
            $team = ProductionTeam::find($id);
            if ($team) {
                $team->delete();
            }
            $responseBody = $this->responseBody(true, "ProductionTeamController", "productionTeamDelete", true);
        } catch (\Exception $ex) {
            $responseBody = $this->responseBody(false, "ProductionTeamController", "productionTeamDelete", $ex);
        }
        return response()->json(["data" => $responseBody]);
    }



    public function updateProductionTeam(Request $request, $id)
    {
        try {
            $designation_id = $request->get('designation_id');
            $team = ProductionTeam::find($id);
            $team->designation_id = $designation_id;
            $status = $team->update();
            $responseBody = $this->responseBody(true, "ProductionTeamController", "updateProductionTeam", $status);
        } catch (\Exception $ex) {
            $responseBody = $this->responseBody(false, "ProductionTeamController", "updateProductionTeam", $ex);
        }
        return response()->json(["data" => $responseBody]);
    }


    private function isAssigned($id)
    {

        $setting = DB::table('pp_order_resource_hrs')->where('designation_id', $id)->first();
        if ($setting) {
            return true;
        }
        return false;
    }



    public function disable(Request $request, $id,$designation_id)
    {

        try {
            $assigned = $this->isAssigned($designation_id);
            if ($assigned) {
                $responseBody = $this->responseBody(false, "disable", "assigned", $assigned);
                return response()->json(["data" => $responseBody]); //if allready assigned settings, terminate this function
            }
            $team = ProductionTeam::find($id);
            $team->status = $request->get('status');
            $disable = $team->save();
            if ($disable) {
                $responseBody = $this->responseBody(true, "disable", "updated", null);
            } else {
                $responseBody = $this->responseBody(false, "disable", "updated", $disable);
            }
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "disable", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }


    /**
     * responseBody
     * This is used to create response.
     * @param success This is the paramter require boolean
     * @param name This is the paramter require ui table name
     * @param message This is the paramter require message content
     * @param result This is the paramter require result as some of data to return client
     * @return Json This returns as response.
     */
    private function responseBody($success, $name, $message, $result)
    {
        $body = [
            "success" => $success,
            "message" => $message,
            "name" => $name,
            "result" => $result
        ];
        return $body;
    }
}
